@@ -14,10 +14,12 @@ module ExampleAppHooks
 
     def final_tasks
       copy_file 'spec/verify_active_record_spec.rb'
+      copy_file 'app/views/_example.html.erb'
       copy_file 'app/views/foo.html'
       copy_file 'app/views/some_templates/bar.html'
       copy_file 'spec/verify_custom_renderers_spec.rb'
       copy_file 'spec/verify_fixture_warning_spec.rb'
+      copy_file 'spec/verify_view_path_stub_spec.rb'
       run('bin/rake db:migrate')
     end
 
@@ -32,6 +34,7 @@ module ExampleAppHooks
     end
 
     def setup_tasks
+      copy_file 'config/initializers/zeitwerk.rb'
       copy_file 'app/models/in_memory/model.rb'
       copy_file 'lib/rails/generators/in_memory/model/model_generator.rb'
       copy_file 'lib/rails/generators/in_memory/model/templates/model.rb.erb'
@@ -54,10 +57,10 @@ module ExampleAppHooks
   end
 
   def self.environment_hooks
-    if defined?(ActiveRecord)
-      AR
-    else
+    if ENV['__RSPEC_NO_AR']
       NoAR
+    else
+      AR
     end
   end
 end
@@ -89,7 +92,7 @@ generate('controller welcome index') # singular
 # request specs are now the default
 generate('rspec:controller wombats --no-request-specs --controller-specs --no-view-specs')
 
-generate('integration_test widgets')
+generate('integration_test widgets') # deprecated
 generate('mailer Notifications signup')
 
 generate('model thing name:string')
@@ -143,6 +146,7 @@ using_source_path(File.expand_path(__dir__)) do
 end
 
 gsub_file 'spec/spec_helper.rb', /^=(begin|end)/, ''
+gsub_file 'spec/rails_helper.rb', /^# Rails\.root\.glob\('spec.support/, "Rails.root.glob('spec/support"
 
 # Warnings are too noisy in the sample apps
 gsub_file 'spec/spec_helper.rb',
@@ -167,4 +171,5 @@ gsub_file 'spec/requests/gadgets_spec.rb',
 gsub_file 'spec/controllers/uploads_controller_spec.rb',
           'skip("Add a hash of attributes valid for your model")',
           '{}'
+
 final_tasks
