@@ -1,5 +1,7 @@
 raise "ActiveRecord is defined but should not be!" if defined?(::ActiveRecord)
 
+require 'active_model'
+
 module InMemory
   module Persistence
     def all
@@ -70,11 +72,13 @@ module InMemory
       self.class.all << self
       true
     end
+    alias :save! :save
 
     def destroy
       self.class.all.delete(self)
       true
     end
+    alias :destroy! :destroy
 
     def reload(*)
       self
