@@ -4,7 +4,7 @@ module RSpec
       # Matcher for template rendering.
       module RenderTemplate
         # @private
-        class RenderTemplateMatcher < RSpec::Matchers::BuiltIn::BaseMatcher
+        class RenderTemplateMatcher < RSpec::Rails::Matchers::BaseMatcher
           def initialize(scope, expected, message = nil)
             @expected = Symbol === expected ? expected.to_s : expected
             @message = message
@@ -29,6 +29,7 @@ module RSpec
           def check_redirect
             response = @scope.response
             return unless response.respond_to?(:redirect?) && response.redirect?
+
             @redirect_is = @scope.send(:normalize_argument_to_redirection, response.location)
           end
 
