@@ -42,6 +42,13 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     ActiveJob::Base.logger = original_logger
   end
 
+  around do |example|
+    original_value = RSpec::Mocks.configuration.verify_partial_doubles?
+    example.run
+  ensure
+    RSpec::Mocks.configuration.verify_partial_doubles = original_value
+  end
+
   let(:heavy_lifting_job) do
     Class.new(ActiveJob::Base) do
       def perform; end
@@ -64,6 +71,20 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     end
   end
 
+  let(:two_args_job) do
+    Class.new(ActiveJob::Base) do
+      def perform(one, two); end
+      def self.name; "TwoArgsJob"; end
+    end
+  end
+
+  let(:keyword_args_job) do
+    Class.new(ActiveJob::Base) do
+      def perform(one:, two:); end
+      def self.name; "KeywordArgsJob"; end
+    end
+  end
+
   before do
     ActiveJob::Base.queue_adapter = :test
   end
@@ -138,7 +159,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     it "fails when job is not enqueued" do
       expect {
         expect { }.to have_enqueued_job
-      }.to raise_error(/expected to enqueue exactly 1 jobs, but enqueued 0/)
+      }.to fail_with(/expected to enqueue exactly 1 jobs, but enqueued 0/)
     end
 
     it "fails when too many jobs enqueued" do
@@ -147,20 +168,20 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
           heavy_lifting_job.perform_later
           heavy_lifting_job.perform_later
         }.to have_enqueued_job.exactly(1)
-      }.to raise_error(/expected to enqueue exactly 1 jobs, but enqueued 2/)
+      }.to fail_with(/expected to enqueue exactly 1 jobs, but enqueued 2/)
     end
 
     it "reports correct number in fail error message" do
       heavy_lifting_job.perform_later
       expect {
         expect { }.to have_enqueued_job.exactly(1)
-      }.to raise_error(/expected to enqueue exactly 1 jobs, but enqueued 0/)
+      }.to fail_with(/expected to enqueue exactly 1 jobs, but enqueued 0/)
     end
 
     it "fails when negated and job is enqueued" do
       expect {
         expect { heavy_lifting_job.perform_later }.not_to have_enqueued_job
-      }.to raise_error(/expected not to enqueue at least 1 jobs, but enqueued 1/)
+      }.to fail_with(/expected not to enqueue at least 1 jobs, but enqueued 1/)
     end
 
     it "fails when negated and several jobs enqueued" do
@@ -169,7 +190,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
           heavy_lifting_job.perform_later
           heavy_lifting_job.perform_later
         }.not_to have_enqueued_job
-      }.to raise_error(/expected not to enqueue at least 1 jobs, but enqueued 2/)
+      }.to fail_with(/expected not to enqueue at least 1 jobs, but enqueued 2/)
     end
 
     it "passes with job name" do
@@ -224,7 +245,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     it "generates failure message with at least hint" do
       expect {
         expect { }.to have_enqueued_job.at_least(:once)
-      }.to raise_error(/expected to enqueue at least 1 jobs, but enqueued 0/)
+      }.to fail_with(/expected to enqueue at least 1 jobs, but enqueued 0/)
     end
 
     it "generates failure message with at most hint" do
@@ -233,7 +254,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
           hello_job.perform_later
           hello_job.perform_later
         }.to have_enqueued_job.at_most(:once)
-      }.to raise_error(/expected to enqueue at most 1 jobs, but enqueued 2/)
+      }.to fail_with(/expected to enqueue at most 1 jobs, but enqueued 2/)
     end
 
     it "passes with provided queue name as string" do
@@ -248,6 +269,40 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       }.to have_enqueued_job.on_queue(:low)
     end
 
+    it "passes with provided priority number as integer" do
+      expect {
+        hello_job.set(priority: 2).perform_later
+      }.to have_enqueued_job.at_priority(2)
+    end
+
+    it "passes with provided priority number as string" do
+      expect {
+        hello_job.set(priority: 2).perform_later
+      }.to have_enqueued_job.at_priority("2")
+    end
+
+    it "fails when the priority wan't set" do
+      expect {
+        expect {
+          hello_job.perform_later
+        }.to have_enqueued_job.at_priority(2)
+      }.to fail_with(/expected to enqueue exactly 1 jobs, with priority 2, but enqueued 0.+ with no priority specified/m)
+    end
+
+    it "fails when the priority was set to a different value" do
+      expect {
+        expect {
+          hello_job.set(priority: 1).perform_later
+        }.to have_enqueued_job.at_priority(2)
+      }.to fail_with(/expected to enqueue exactly 1 jobs, with priority 2, but enqueued 0.+ with priority 1/m)
+    end
+
+    pending "accepts matchers as arguments to at_priority" do
+      expect {
+        hello_job.set(priority: 1).perform_later
+      }.to have_enqueued_job.at_priority(eq(1))
+    end
+
     it "passes with provided at date" do
       date = Date.tomorrow.noon
       expect {
@@ -277,7 +332,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       travel_to time do
         expect {
           expect { hello_job.set(wait: 5).perform_later }.to have_enqueued_job.at(time + 5)
-        }.to raise_error(/expected to enqueue exactly 1 jobs/)
+        }.to fail_with(/expected to enqueue exactly 1 jobs/)
       end
     end
 
@@ -301,7 +356,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
         expect {
           hello_job.perform_later
         }.to have_enqueued_job.at(date)
-      }.to raise_error(/expected to enqueue exactly 1 jobs, at .+ but enqueued 0/)
+      }.to fail_with(/expected to enqueue exactly 1 jobs, at .+ but enqueued 0/)
     end
 
     it "has an enqueued job when not providing at and there is a wait" do
@@ -324,6 +379,56 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       }.to have_enqueued_job.with(42, "David")
     end
 
+    describe "verifying the arguments passed match the job's signature" do
+      it "fails if there is an arity mismatch" do
+        expect {
+          expect {
+            two_args_job.perform_later(1)
+          }.to have_enqueued_job.with(1)
+        }.to fail_with(/Incorrect arguments passed to TwoArgsJob: Wrong number of arguments/)
+      end
+
+      it "fails if there is a keyword/positional arguments mismatch" do
+        expect {
+          expect {
+            keyword_args_job.perform_later(1, 2)
+          }.to have_enqueued_job.with(1, 2)
+        }.to fail_with(/Incorrect arguments passed to KeywordArgsJob: Missing required keyword arguments/)
+      end
+
+      context "with partial double verification disabled" do
+        before do
+          RSpec::Mocks.configuration.verify_partial_doubles = false
+        end
+
+        it "skips signature checks" do
+          expect { two_args_job.perform_later(1) }.to have_enqueued_job.with(1)
+        end
+      end
+
+      context "when partial double verification is temporarily suspended" do
+        it "skips signature checks" do
+          without_partial_double_verification {
+            expect {
+              two_args_job.perform_later(1)
+            }.to have_enqueued_job.with(1)
+          }
+        end
+      end
+
+      context "without rspec-mocks loaded" do
+        before do
+          # Its hard for us to unload this, but its fairly safe to assume that we can run
+          # a defined? check, this just mocks the "short circuit"
+          allow(::RSpec::Mocks).to receive(:respond_to?).with(:configuration) { false }
+        end
+
+        it "skips signature checks" do
+          expect { two_args_job.perform_later(1) }.to have_enqueued_job.with(1)
+        end
+      end
+    end
+
     it "passes with provided arguments containing global id object" do
       global_id_object = GlobalIdModel.new("42")
 
@@ -340,15 +445,15 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
 
     it "generates failure message with all provided options" do
       date = Date.tomorrow.noon
-      message = "expected to enqueue exactly 2 jobs, with [42], on queue low, at #{date}, but enqueued 0" \
+      message = "expected to enqueue exactly 2 jobs, with [42], on queue low, at #{date}, with priority 5, but enqueued 0" \
                 "\nQueued jobs:" \
-                "\n  HelloJob job with [1], on queue default"
+                "\n  HelloJob job with [1], on queue default, with no priority specified"
 
       expect {
         expect {
           hello_job.perform_later(1)
-        }.to have_enqueued_job(hello_job).with(42).on_queue("low").at(date).exactly(2).times
-      }.to raise_error(message)
+        }.to have_enqueued_job(hello_job).with(42).on_queue("low").at(date).at_priority(5).exactly(2).times
+      }.to fail_with(message)
     end
 
     it "throws descriptive error when no test adapter set" do
@@ -454,7 +559,47 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     it "fails when job is not enqueued" do
       expect {
         expect(heavy_lifting_job).to have_been_enqueued
-      }.to raise_error(/expected to enqueue exactly 1 jobs, but enqueued 0/)
+      }.to fail_with(/expected to enqueue exactly 1 jobs, but enqueued 0/)
+    end
+
+    describe "verifying the arguments passed match the job's signature" do
+      it "fails if there is an arity mismatch" do
+        two_args_job.perform_later(1)
+
+        expect {
+          expect(two_args_job).to have_been_enqueued.with(1)
+        }.to fail_with(/Incorrect arguments passed to TwoArgsJob: Wrong number of arguments/)
+      end
+
+      it "fails if there is a keyword/positional arguments mismatch" do
+        keyword_args_job.perform_later(1, 2)
+
+        expect {
+          expect(keyword_args_job).to have_been_enqueued.with(1, 2)
+        }.to fail_with(/Incorrect arguments passed to KeywordArgsJob: Missing required keyword arguments/)
+      end
+
+      context "with partial double verification disabled" do
+        before do
+          RSpec::Mocks.configuration.verify_partial_doubles = false
+        end
+
+        it "skips signature checks" do
+          keyword_args_job.perform_later(1, 2)
+
+          expect(keyword_args_job).to have_been_enqueued.with(1, 2)
+        end
+      end
+
+      context "when partial double verification is temporarily suspended" do
+        it "skips signature checks" do
+          keyword_args_job.perform_later(1, 2)
+
+          without_partial_double_verification {
+            expect(keyword_args_job).to have_been_enqueued.with(1, 2)
+          }
+        end
+      end
     end
 
     it "fails when negated and several jobs enqueued" do
@@ -462,7 +607,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       heavy_lifting_job.perform_later
       expect {
         expect(heavy_lifting_job).not_to have_been_enqueued
-      }.to raise_error(/expected not to enqueue at least 1 jobs, but enqueued 2/)
+      }.to fail_with(/expected not to enqueue at least 1 jobs, but enqueued 2/)
     end
 
     it "accepts composable matchers as an at date" do
@@ -511,7 +656,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     it "fails when job is not performed" do
       expect {
         expect { }.to have_performed_job
-      }.to raise_error(/expected to perform exactly 1 jobs, but performed 0/)
+      }.to fail_with(/expected to perform exactly 1 jobs, but performed 0/)
     end
 
     it "fails when too many jobs performed" do
@@ -520,20 +665,20 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
           heavy_lifting_job.perform_later
           heavy_lifting_job.perform_later
         }.to have_performed_job.exactly(1)
-      }.to raise_error(/expected to perform exactly 1 jobs, but performed 2/)
+      }.to fail_with(/expected to perform exactly 1 jobs, but performed 2/)
     end
 
     it "reports correct number in fail error message" do
       heavy_lifting_job.perform_later
       expect {
         expect { }.to have_performed_job.exactly(1)
-      }.to raise_error(/expected to perform exactly 1 jobs, but performed 0/)
+      }.to fail_with(/expected to perform exactly 1 jobs, but performed 0/)
     end
 
     it "fails when negated and job is performed" do
       expect {
         expect { heavy_lifting_job.perform_later }.not_to have_performed_job
-      }.to raise_error(/expected not to perform exactly 1 jobs, but performed 1/)
+      }.to fail_with(/expected not to perform exactly 1 jobs, but performed 1/)
     end
 
     it "passes with job name" do
@@ -588,7 +733,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     it "generates failure message with at least hint" do
       expect {
         expect { }.to have_performed_job.at_least(:once)
-      }.to raise_error(/expected to perform at least 1 jobs, but performed 0/)
+      }.to fail_with(/expected to perform at least 1 jobs, but performed 0/)
     end
 
     it "generates failure message with at most hint" do
@@ -597,7 +742,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
           hello_job.perform_later
           hello_job.perform_later
         }.to have_performed_job.at_most(:once)
-      }.to raise_error(/expected to perform at most 1 jobs, but performed 2/)
+      }.to fail_with(/expected to perform at most 1 jobs, but performed 2/)
     end
 
     it "passes with provided queue name as string" do
@@ -641,15 +786,15 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
 
     it "generates failure message with all provided options" do
       date = Date.tomorrow.noon
-      message = "expected to perform exactly 2 jobs, with [42], on queue low, at #{date}, but performed 0" \
+      message = "expected to perform exactly 2 jobs, with [42], on queue low, at #{date}, with priority 5, but performed 0" \
                 "\nQueued jobs:" \
-                "\n  HelloJob job with [1], on queue default"
+                "\n  HelloJob job with [1], on queue default, with no priority specified"
 
       expect {
         expect {
           hello_job.perform_later(1)
-        }.to have_performed_job(hello_job).with(42).on_queue("low").at(date).exactly(2).times
-      }.to raise_error(message)
+        }.to have_performed_job(hello_job).with(42).on_queue("low").at(date).at_priority(5).exactly(2).times
+      }.to fail_with(message)
     end
 
     it "throws descriptive error when no test adapter set" do
@@ -734,7 +879,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     it "fails when job is not performed" do
       expect {
         expect(heavy_lifting_job).to have_been_performed
-      }.to raise_error(/expected to perform exactly 1 jobs, but performed 0/)
+      }.to fail_with(/expected to perform exactly 1 jobs, but performed 0/)
     end
   end
 
