@@ -20,6 +20,10 @@ if RSpec::Rails::FeatureCheck.has_active_job?
     def test_email; end
   end
 
+  class NonMailerJob < ActiveJob::Base
+    def perform; end
+  end
+
   if RSpec::Rails::FeatureCheck.has_action_mailer_unified_delivery?
     class UnifiedMailer < ActionMailer::Base
       self.delivery_job = ActionMailer::MailDeliveryJob
@@ -56,6 +60,13 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
     ActiveJob::Base.logger = original_logger
   end
 
+  around do |example|
+    original_value = RSpec::Mocks.configuration.verify_partial_doubles?
+    example.run
+  ensure
+    RSpec::Mocks.configuration.verify_partial_doubles = original_value
+  end
+
   describe "have_enqueued_mail" do
     it "passes when a mailer method is called with deliver_later" do
       expect {
@@ -95,6 +106,10 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
       expect { }.not_to have_enqueued_email
     end
 
+    it "passes when negated with 0 arguments and a non-mailer job is enqueued" do
+      expect { NonMailerJob.perform_later }.not_to have_enqueued_email
+    end
+
     it "passes when only given mailer argument" do
       expect {
         TestMailer.test_email.deliver_later
@@ -110,7 +125,7 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
         expect {
           AnotherTestMailer.test_email.deliver_later
         }.to have_enqueued_mail(TestMailer)
-      }.to raise_error(/expected to enqueue TestMailer exactly 1 time but enqueued 0/)
+      }.to fail_with(/expected to enqueue TestMailer exactly 1 time but enqueued 0/)
     end
 
     it "counts only emails enqueued in the block" do
@@ -127,7 +142,7 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
           TestMailer.test_email.deliver_later
           TestMailer.test_email.deliver_later
         }.to have_enqueued_mail(TestMailer, :test_email).exactly(1)
-      }.to raise_error(/expected to enqueue TestMailer.test_email exactly 1 time/)
+      }.to fail_with(/expected to enqueue TestMailer.test_email exactly 1 time/)
     end
 
     it "matches based on mailer class and method name" do
@@ -149,7 +164,7 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
         expect {
           TestMailer.test_email.deliver_later
         }.not_to have_enqueued_mail(TestMailer, :test_email)
-      }.to raise_error(/expected not to enqueue TestMailer.test_email at least 1 time but enqueued 1/)
+      }.to fail_with(/expected not to enqueue TestMailer.test_email at least 1 time but enqueued 1/)
     end
 
     it "passes with :once count" do
@@ -189,19 +204,19 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
     it "generates a failure message when given 0 argument" do
       expect {
         expect { }.to have_enqueued_mail.at_least(:once)
-      }.to raise_error(/expected to enqueue ActionMailer::Base at least 1 time but enqueued 0/)
+      }.to fail_with(/expected to enqueue ActionMailer::Base at least 1 time but enqueued 0/)
     end
 
     it "generates a failure message when given only mailer argument" do
       expect {
         expect { }.to have_enqueued_mail(TestMailer).at_least(:once)
-      }.to raise_error(/expected to enqueue TestMailer at least 1 time but enqueued 0/)
+      }.to fail_with(/expected to enqueue TestMailer at least 1 time but enqueued 0/)
     end
 
     it "generates a failure message with at least hint" do
       expect {
         expect { }.to have_enqueued_mail(TestMailer, :test_email).at_least(:once)
-      }.to raise_error(/expected to enqueue TestMailer.test_email at least 1 time but enqueued 0/)
+      }.to fail_with(/expected to enqueue TestMailer.test_email at least 1 time but enqueued 0/)
     end
 
     it "generates a failure message with at most hint" do
@@ -210,7 +225,7 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
           TestMailer.test_email.deliver_later
           TestMailer.test_email.deliver_later
         }.to have_enqueued_mail(TestMailer, :test_email).at_most(:once)
-      }.to raise_error(/expected to enqueue TestMailer.test_email at most 1 time but enqueued 2/)
+      }.to fail_with(/expected to enqueue TestMailer.test_email at most 1 time but enqueued 2/)
     end
 
     it "passes for mailer methods that accept arguments when the provided argument matcher is not used" do
@@ -243,16 +258,47 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
       }.not_to have_enqueued_mail(TestMailer, :email_with_args).with(3, 4)
     end
 
+    describe "verifying the arguments passed match the mailer's signature" do
+      it "fails if there is a mismatch" do
+        expect {
+          expect {
+            TestMailer.email_with_args(1).deliver_later
+          }.to have_enqueued_mail(TestMailer, :email_with_args).with(1)
+        }.to fail_with(/Incorrect arguments passed to TestMailer: Wrong number of arguments/)
+      end
+
+      context "with partial double verification disabled" do
+        before do
+          RSpec::Mocks.configuration.verify_partial_doubles = false
+        end
+
+        it "skips signature checks" do
+          expect { TestMailer.email_with_args(1).deliver_later }
+            .to have_enqueued_mail(TestMailer, :email_with_args).with(1)
+        end
+      end
+
+      context "when partial double verification is temporarily suspended" do
+        it "skips signature checks" do
+          without_partial_double_verification {
+            expect {
+              TestMailer.email_with_args(1).deliver_later
+            }.to have_enqueued_mail(TestMailer, :email_with_args).with(1)
+          }
+        end
+      end
+    end
+
     it "generates a failure message" do
       expect {
         expect { }.to have_enqueued_email(TestMailer, :test_email)
-      }.to raise_error(/expected to enqueue TestMailer.test_email/)
+      }.to fail_with(/expected to enqueue TestMailer.test_email/)
     end
 
     it "generates a failure message with arguments" do
       expect {
         expect { }.to have_enqueued_email(TestMailer, :email_with_args).with(1, 2)
-      }.to raise_error(/expected to enqueue TestMailer.email_with_args exactly 1 time with \[1, 2\], but enqueued 0/)
+      }.to fail_with(/expected to enqueue TestMailer.email_with_args exactly 1 time with \[1, 2\], but enqueued 0/)
     end
 
     it "passes when deliver_later is called with a wait_until argument" do
@@ -270,7 +316,7 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
         expect {
           TestMailer.test_email.deliver_later(wait_until: send_time + 1)
         }.to have_enqueued_email(TestMailer, :test_email).at(send_time)
-      }.to raise_error(/expected to enqueue TestMailer.test_email exactly 1 time at #{send_time.strftime('%F %T')}/)
+      }.to fail_with(/expected to enqueue TestMailer.test_email exactly 1 time at #{send_time.strftime('%F %T')}/)
     end
 
     it "accepts composable matchers as an at date" do
@@ -293,15 +339,10 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
         expect {
           TestMailer.test_email.deliver_later(queue: 'not_urgent_mail')
         }.to have_enqueued_email(TestMailer, :test_email).on_queue('urgent_mail')
-      }.to raise_error(/expected to enqueue TestMailer.test_email exactly 1 time on queue urgent_mail/)
+      }.to fail_with(/expected to enqueue TestMailer.test_email exactly 1 time on queue urgent_mail/)
     end
 
     it "generates a failure message with unmatching enqueued mail jobs" do
-      non_mailer_job = Class.new(ActiveJob::Base) do
-        def perform; end
-        def self.name; "NonMailerJob"; end
-      end
-
       send_time = Date.tomorrow.noon
       queue = 'urgent_mail'
 
@@ -312,11 +353,11 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
 
       expect {
         expect {
-          non_mailer_job.perform_later
+          NonMailerJob.perform_later
           TestMailer.test_email.deliver_later
           TestMailer.email_with_args(3, 4).deliver_later(wait_until: send_time, queue: queue)
         }.to have_enqueued_email(TestMailer, :email_with_args).with(1, 2)
-      }.to raise_error(message)
+      }.to fail_with(message)
     end
 
     it "throws descriptive error when no test adapter set" do
@@ -365,7 +406,13 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
       }
     end
 
-    context 'when parameterized', skip: !RSpec::Rails::FeatureCheck.has_action_mailer_parameterized? do
+    context 'when parameterized' do
+      before do
+        unless RSpec::Rails::FeatureCheck.has_action_mailer_parameterized?
+          skip "This version of Rails does not support parameterized mailers"
+        end
+      end
+
       it "passes when mailer is parameterized" do
         expect {
           TestMailer.with('foo' => 'bar').test_email.deliver_later
@@ -388,6 +435,14 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
           TestMailer.with('foo' => 'bar').email_with_args(1, 2).deliver_later
         }.to have_enqueued_mail(TestMailer, :email_with_args).with({ 'foo' => 'bar' }, 1, 2)
       end
+
+      it "fails if the arguments do not match the mailer method's signature" do
+        expect {
+          expect {
+            TestMailer.with('foo' => 'bar').email_with_args(1).deliver_later
+          }.to have_enqueued_mail(TestMailer, :email_with_args).with({ 'foo' => 'bar' }, 1)
+        }.to raise_error(/Incorrect arguments passed to TestMailer: Wrong number of arguments/)
+      end
     end
 
     context 'mailer job is unified', skip: !RSpec::Rails::FeatureCheck.has_action_mailer_unified_delivery? do
@@ -435,6 +490,16 @@ RSpec.describe "HaveEnqueuedMail matchers", skip: !RSpec::Rails::FeatureCheck.ha
           UnifiedMailerWithDeliveryJobSubClass.test_email.deliver_later
         }.to have_enqueued_mail(UnifiedMailerWithDeliveryJobSubClass, :test_email)
       end
+
+      it "fails if the arguments do not match the mailer method's signature" do
+        expect {
+          expect {
+            UnifiedMailer.with('foo' => 'bar').email_with_args(1).deliver_later
+          }.to have_enqueued_mail(UnifiedMailer, :email_with_args).with(
+            a_hash_including(params: { 'foo' => 'bar' }, args: [1])
+          )
+        }.to fail_with(/Incorrect arguments passed to UnifiedMailer: Wrong number of arguments/)
+      end
     end
   end
 end
