@@ -9,24 +9,32 @@ RSpec.describe "route_to" do
   it "provides a description" do
     matcher = route_to("these" => "options")
     matcher.matches?(get: "path")
-    expect(matcher.description).to eq("route {:get=>\"path\"} to {\"these\"=>\"options\"}")
+
+    description =
+      if RUBY_VERSION >= '3.4'
+        "route {get: \"path\"} to {\"these\" => \"options\"}"
+      else
+        "route {:get=>\"path\"} to {\"these\"=>\"options\"}"
+      end
+
+    expect(matcher.description).to eq(description)
   end
 
   it "delegates to assert_recognizes" do
-    expect(self).to receive(:assert_recognizes).with({"these" => "options"}, {method: :get, path: "path"}, {})
-    expect({get: "path"}).to route_to("these" => "options")
+    expect(self).to receive(:assert_recognizes).with({ "these" => "options" }, { method: :get, path: "path" }, {})
+    expect({ get: "path" }).to route_to("these" => "options")
   end
 
   context "with shortcut syntax" do
     it "routes with extra options" do
-      expect(self).to receive(:assert_recognizes).with({controller: "controller", action: "action", extra: "options"}, {method: :get, path: "path"}, {})
+      expect(self).to receive(:assert_recognizes).with({ controller: "controller", action: "action", extra: "options" }, { method: :get, path: "path" }, {})
       expect(get("path")).to route_to("controller#action", extra: "options")
     end
 
     it "routes without extra options" do
       expect(self).to receive(:assert_recognizes).with(
-        {controller: "controller", action: "action"},
-        {method: :get, path: "path"},
+        { controller: "controller", action: "action" },
+        { method: :get, path: "path" },
         {}
       )
       expect(get("path")).to route_to("controller#action")
@@ -34,29 +42,29 @@ RSpec.describe "route_to" do
 
     it "routes with one query parameter" do
       expect(self).to receive(:assert_recognizes).with(
-        {controller: "controller", action: "action", queryitem: "queryvalue"},
-        {method: :get, path: "path"},
-        {'queryitem' => 'queryvalue'}
+        { controller: "controller", action: "action", queryitem: "queryvalue" },
+        { method: :get, path: "path" },
+        { 'queryitem' => 'queryvalue' }
       )
       expect(get("path?queryitem=queryvalue")).to route_to("controller#action", queryitem: 'queryvalue')
     end
 
     it "routes with multiple query parameters" do
       expect(self).to receive(:assert_recognizes).with(
-        {controller: "controller", action: "action", queryitem: "queryvalue", qi2: 'qv2'},
-        {method: :get, path: "path"},
-        {'queryitem' => 'queryvalue', 'qi2' => 'qv2'}
+        { controller: "controller", action: "action", queryitem: "queryvalue", qi2: 'qv2' },
+        { method: :get, path: "path" },
+        { 'queryitem' => 'queryvalue', 'qi2' => 'qv2' }
       )
       expect(get("path?queryitem=queryvalue&qi2=qv2")).to route_to("controller#action", queryitem: 'queryvalue', qi2: 'qv2')
     end
 
     it "routes with nested query parameters" do
       expect(self).to receive(:assert_recognizes).with(
-        {:controller => "controller", :action => "action", 'queryitem' => {'qi2' => 'qv2'}},
-        {method: :get, path: "path"},
-        {'queryitem' => {'qi2' => 'qv2'}}
+        { :controller => "controller", :action => "action", 'queryitem' => { 'qi2' => 'qv2' } },
+        { method: :get, path: "path" },
+        { 'queryitem' => { 'qi2' => 'qv2' } }
       )
-      expect(get("path?queryitem[qi2]=qv2")).to route_to("controller#action", 'queryitem' => {'qi2' => 'qv2'})
+      expect(get("path?queryitem[qi2]=qv2")).to route_to("controller#action", 'queryitem' => { 'qi2' => 'qv2' })
     end
 
   end
@@ -65,7 +73,7 @@ RSpec.describe "route_to" do
     context "when assert_recognizes passes" do
       it "passes" do
         expect do
-          expect({get: "path"}).to route_to("these" => "options")
+          expect({ get: "path" }).to route_to("these" => "options")
         end.to_not raise_exception
       end
     end
@@ -73,10 +81,10 @@ RSpec.describe "route_to" do
     context "when assert_recognizes fails with an assertion failure" do
       it "fails with message from assert_recognizes" do
         def assert_recognizes(*)
-          raise ActiveSupport::TestCase::Assertion.new("this message")
+          raise ActiveSupport::TestCase::Assertion, "this message"
         end
         expect do
-          expect({get: "path"}).to route_to("these" => "options")
+          expect({ get: "path" }).to route_to("these" => "options")
         end.to raise_error(RSpec::Expectations::ExpectationNotMetError, "this message")
       end
     end
@@ -84,10 +92,10 @@ RSpec.describe "route_to" do
     context "when assert_recognizes fails with a routing error" do
       it "fails with message from assert_recognizes" do
         def assert_recognizes(*)
-          raise ActionController::RoutingError.new("this message")
+          raise ActionController::RoutingError, "this message"
         end
         expect do
-          expect({get: "path"}).to route_to("these" => "options")
+          expect({ get: "path" }).to route_to("these" => "options")
         end.to raise_error(RSpec::Expectations::ExpectationNotMetError, "this message")
       end
     end
@@ -98,7 +106,7 @@ RSpec.describe "route_to" do
           raise "oops"
         end
         expect do
-          expect({get: "path"}).to route_to("these" => "options")
+          expect({ get: "path" }).to route_to("these" => "options")
         end.to raise_exception("oops")
       end
     end
@@ -107,19 +115,26 @@ RSpec.describe "route_to" do
   context "with should_not" do
     context "when assert_recognizes passes" do
       it "fails with custom message" do
+        message =
+          if RUBY_VERSION >= '3.4'
+            /expected \{get: "path"\} not to route to \{"these" => "options"\}/
+          else
+            /expected \{:get=>"path"\} not to route to \{"these"=>"options"\}/
+          end
+
         expect {
-          expect({get: "path"}).not_to route_to("these" => "options")
-        }.to raise_error(/expected \{:get=>"path"\} not to route to \{"these"=>"options"\}/)
+          expect({ get: "path" }).not_to route_to("these" => "options")
+        }.to raise_error(message)
       end
     end
 
     context "when assert_recognizes fails with an assertion failure" do
       it "passes" do
         def assert_recognizes(*)
-          raise ActiveSupport::TestCase::Assertion.new("this message")
+          raise ActiveSupport::TestCase::Assertion, "this message"
         end
         expect do
-          expect({get: "path"}).not_to route_to("these" => "options")
+          expect({ get: "path" }).not_to route_to("these" => "options")
         end.to_not raise_error
       end
     end
@@ -127,10 +142,10 @@ RSpec.describe "route_to" do
     context "when assert_recognizes fails with a routing error" do
       it "passes" do
         def assert_recognizes(*)
-          raise ActionController::RoutingError.new("this message")
+          raise ActionController::RoutingError, "this message"
         end
         expect do
-          expect({get: "path"}).not_to route_to("these" => "options")
+          expect({ get: "path" }).not_to route_to("these" => "options")
         end.to_not raise_error
       end
     end
@@ -141,7 +156,7 @@ RSpec.describe "route_to" do
           raise "oops"
         end
         expect do
-          expect({get: "path"}).not_to route_to("these" => "options")
+          expect({ get: "path" }).not_to route_to("these" => "options")
         end.to raise_exception("oops")
       end
     end
@@ -152,7 +167,7 @@ RSpec.describe "route_to" do
       raise ActiveSupport::TestCase::Assertion, "this message"
     end
     expect do
-      expect({"this" => "path"}).to route_to("these" => "options")
+      expect({ "this" => "path" }).to route_to("these" => "options")
     end.to raise_error("this message")
   end
 end
